function [D0,D1] = D0D1_0(cfl,rhofl,alphapfl,cpfl,etafl,detadT,detadrho, cLsl,cTsl,rhosl, T0,f,a)
% This function calculates the force coefficients D_0^0 and D_1^0 for
%  a solid particle in the long-wavelength limit

% Angular frequency
omega = 2*pi*f;
% Fluid parameters dependent on given parameters:
% fluid compressibility kappasfl, ratio of specific heat gammafl, 
% and thermal coefficient Bc
kappasfl = 1/(rhofl*cfl^2);
gammafl = 1 + alphapfl^2*T0/(rhofl*cpfl*kappasfl);
Bc = (1 - gammafl)*detadT/(alphapfl*etafl) - rhofl*detadrho/etafl;

% Solid compressibility
kappassl = 1/((cLsl^2 - 4/3*cTsl^2)*rhosl);

% Particle/Surrounding fluid parameter ratios
rho = rhosl/rhofl;
kappas = kappassl/kappasfl;

% Boundary layer deltas and wave numbers
deltas = sqrt(2*etafl/(rhofl*omega));
k0 = omega/cfl;
ks = (1 + i)/deltas;
x0 = k0*a;
xs = ks*a;

% Scattering coefficients (n=0, n=1, and n=2)
alphac0 = -x0^3*i/3*(1 - kappas);
alphac1 = -x0^3*i/3*(rho - 1)*(3 - 3*i*xs - xs^2)/(xs^2*(2*rho + 1) - 9*(1 - xs*i));
alphas1 = x0*(rho - 1)*xs^2*exp(-i*xs)*i/(xs^2*(2*rho + 1) - 9*(1 - xs*i));
alphac2 = 2*i*x0^5/(135*xs^2)*(15*(1 - xs*i) - 6*xs^2 + xs^3*i)/(xs*i - 1);
alphas2 = -x0^2*i/9*xs*exp(-i*xs)/(xs*i - 1);

% Smn_0^0 and Smn_1^0 coefficients
S000 = 1/(3*xs^2)*x0^3;
S001 = 1/(3*xs^2)*x0^3;
S0c0 = 2*i/3;
S0s0 = -2*i*exp(-xs)*(Bc + 1)*x0^2/xs^2;
Sc00 = 2*i/3;
Sc01 = 2*i/3;
Scc0 = 6/(xs^2*x0^3);
Scc1 = 135/(xs^2*x0^5);
Scs0 = ((-xs^7 + xs^6 - 14*xs^5 + 18*xs^4 - 48*xs^3 - 96*xs^2 - 144*xs - 144)*exp(-xs) + xs^6*expint( xs)*(xs^2 + 12))/(24*xs^4)/x0;
Scs1 = (-3*i*(-xs^7 + xs^6 - 2*xs^5 + 6*xs^4 + 48*xs^3 + 168*xs^2 + 360*xs + 360)*exp(-xs) - 3*i*xs^8*expint( xs))/(4*xs^5)/x0^2;
Ss01 = 6*i/5*exp(xs*i)*x0^2/xs^2;
Ssc1 = ((xs^10 + 18*xs^8)*expint( -i*xs) - (xs^9*i + 16*i*xs^7 + xs^8 - 12*i*xs^5 + 12*xs^6 - 288*i*xs^3 + 12*xs^4 + 4320*i*xs + 1728*xs^2 - 4320)*exp(xs*i))/(32*xs^4)/x0^3;
Sss1 = (-2*i*xs^8*(xs^2 + 9)*expint( (1 - i)*xs) + (-1080*i + (-1 + i)*xs^9 + xs^8 + (-10 + 8*i)*xs^7 + (9 + 3*i)*xs^6 + (9 + 57*i)*xs^5 + (-72 + 177*i)*xs^4 + (-432 + 288*i)*xs^3 - (1080 + 72*i)*xs^2 - (1080 + 1080*i)*xs)*exp((-1 + i)*xs))/(4*xs^7);

% D0^0 and D1^0 for a solid particle in a surrounding fluid
D0 = S000 + S0c0*conj(alphac1) + S0s0*conj(alphas1) + Sc00*alphac0 + Scc0*alphac0*conj(alphac1) + Scs0*alphac0*conj(alphas1);
D1 = S001 + Sc01*alphac1 + Scc1*alphac1*conj(alphac2) + Scs1*alphac1*conj(alphas2) + Ss01*alphas1 + Ssc1*alphas1*conj(alphac2) + Sss1*alphas1*conj(alphas2);