function DnDelT0 = DnDelT0(cfl,rhofl,cpfl,kthfl,P0,ac,f,a,n,t)
% This function calculates the force coefficients D_n^DelT0 for 
% a solid particle in the long-wavelength limit

% Angular frequency
omega = 2*pi*f;
% Fluid parameters dependent on given parameters:
% fluid compressibility kappasfl and heat diffusivity Dthfl
kappasfl = 1/(rhofl*cfl^2);
Dthfl = kthfl/(rhofl*cpfl);

% Normalized wave numbers
x0 = omega/cfl*a;
xDth = a/sqrt(4*Dthfl*t);

% Integrant from Eq. (50)
Integrant = @(r) P0*a^2/(3*kthfl)*1./r.*erfc(xDth*r).*(pi./(2.*x0.*r)).*(x0.*(r-1./(3.*r)).*(besselj(n+1/2,x0*r).^2-besselj(n+1+1/2,x0*r).^2)-(1-1./r.^2).*besselj(n+1/2,x0*r).*besselj(n+1+1/2,x0*r)) ;

% DnDelT0
DnDelT0 = 2*ac*x0^2*integral(Integrant,1,Inf);