% Supplemental material for the article: 
% Acoustic radiation force on a heated spherical particle in a fluid 
% including scattering and microstreaming from a standing ultrasound wave
% Phys. Rev. E. (2023)
% Authors: Bjørn G. Winckelmann and Henrik Bruus

% This script calculates the long-wavelength limit acoustic contrast
% factor Phiac for the case of a polystyrene particle in water.

% All parameters are stated in SI units

% General problem parameters:
% frequency f, equilibrium temperature T0, particle radius a,
% asymptotic surface temperature DelT0surf, and time t:
f = 1*10^6;
T0 = 300;
a = 2*10^(-6);
DelT0surf = 1;
t = 1;

% FLuid and particle parameters:
% Water parameters:
% speed of sound cfl, density rhofl, thermal expansion coeff. alphapfl,
% specific heat at constant pressure cpfl, thermal conductivity kthfl,
% viscosity etafl, viscosity change per temperature detadT, 
% viscosity change per density detadrho, and relative change in speed of
% sound per temperature ac.
cfl = 1502;
rhofl = 996.6;
alphapfl = 2.748*10^(-4);
cpfl = 4181;
kthfl = 6.095*10^(-1);
etafl = 8.538*10^(-4);
detadT = -1.896*10^(-5);
detadrho = -2.0185*10^(-7);
ac = 0.0016897;
% Polystyrene parameters:
% longditudinal and transverse speeds of sound cLsl and cTsl, 
% density rhosl, thermal expansion coeff. alphapsl,
% specific heat at constant pressure cpsl, and thermal conductivity kthsl,
cLsl = 2407.4;
cTsl = 1153.6;
rhosl = 1050;
alphapsl = 2.09*10^(-4);
cpsl = 1240.5;
kthsl = 0.154;
% Power density absorbed by the particle
P0 = 3*DelT0surf*kthfl/a^2;

% Force coefficients D0^0 and D1^0 without temperature gradients 
[D0,D1] = D0D1_0(cfl,rhofl,alphapfl,cpfl,etafl,detadT,detadrho, cLsl,cTsl,rhosl, T0,f,a);

% Normalized wave number x0
x0 = 2*pi*f/cfl*a;

% The acoustic contrast factor without temperature gradients Phiac^0
Phiac0 = 3/(2*x0^3)*real(D0-2*D1);

% Phiac^DelT0 (with the first 51 terms)
temp=0;
for n=0:50
    temp=temp+(n+1)*(-1)^n*DnDelT0(cfl,rhofl,cpfl,kthfl,P0,ac,f,a,n,t);
end
PhiacDelT0 = 3/2*real(temp)/x0^3;

% The acoustic contrast factor Phiac
Phiac = Phiac0 + PhiacDelT0
